@@ -17,17 +17,17 @@
                 "entrée": {
                     "required": False,
                     "type": ["string", "integer"],
-                    "nullable": True,
+                    "nullable": False,
                 },
                 "sortie": {
                     "required": True,
                     "type": ["string", "integer"],
-                    "nullable": True,
+                    "nullable": False,
                 },
                 "params": {
                     "required": False,
                     "type": ["string", "integer"],
-                    "nullable": True,
+                    "nullable": False,
                 },
                 "rétroactions": {
                     "required": False,
